# Basic Tenants
* Ease of Use > Accuracy > Speed (with speed more important with 'fast' selections)
* Availability of models which share information among series
* All models should be probabilistic (upper/lower forecasts)
* New transformations should be applicable to many datasets and models
* New models need only be sometimes applicable
* Fault tolerance: it is perfectly acceptable for model parameters to fail on some datasets, the higher level API will pass over and use others.
* Missing data tolerance: large chunks of data can be missing and model will still produce reasonable results (although lower quality than if data is available)

## Assumptions on Data
* Series will largely be consistent in period, or at least up-sampled to regular intervals
* The most recent data will generally be the most important
* Forecasts are desired for the future immediately following the most recent data.

# Latest :fireworks: :fireworks:
* Replaced ZeroesNaive model with ConstantNaive
* updated the General starting template
* added 'window' to AverageValueNaive
* added :octocat: load_artificial sample dataset
* fixed bug in plot_horizontal where not handling negative series
* major update to Constraint functionality
* GluonTS is no longer part of the default model list (faster tests this way) but is now part of 'best'
* horizontal models_to_use for Mosaic ensembles
* added some intel optimizations to sklearn code if scikit-learn-intelex installed
* fixed a :bug: in rolling_x_regressor where datepart method wasn't actually getting appended
* sped up rolling_x_regressor by reducing concats
* added current_model_file as an option for additional debugging information
* updated PCA and FastICA to be more flexible on n_components
* fixed a bug where unpack_ensemble_models with keep_ensemble=False was still keeping nested ensembles
* impute speed optimizations for fill_mean, use of nan check so runs faster if no nan present
* optimizations to metrics including faster if no NaN present
* :heavy_plus_sign: faster percentile function, used in transforms, basics
* also added nan_checks to switch between numpy na and numpy non-na quantiles/medians
* made fake_date_fill nan method vectorized
* slightly adjusted the upper/lower forecast method for LastValueNaive :crystal_ball:
* updated sliding_window_view to allow Motifs to run on Numpy < 1.20 and also for faster WindowRegression
* updated regressor_used and used_regressor_check so they should be more reliably filled.
* changed behavior where import_templates would fail if model_list not satisified. Still fails, but now only for the "only" import option
* added :chart_with_upwards_trend: when a model in validation is the best so far that round
* addition of "auto" and "max" num_validations with auto set as default
* addition of new metrics: mqae, oda, maxe

### New Model Checklist:
	* Add to ModelMonster in auto_model.py
	* add to appropriate model_lists: all, recombination_approved if so, no_shared if so
	* add to model table in extended_tutorial.md (most columns here have an equivalent model_list)
	* if model has regressors, make sure it meets Simulation Forecasting needs (method="regressor", fails on no regressor if "User")

## New Transformer Checklist:
	* Make sure that if it modifies the size (more/fewer columns or rows) it returns pd.DataFrame with proper index/columns
	* depth of recombination is?
	* add to "all" transformer_dict
	* add to no_params or external if so
	* add to no_shared if so, in auto_model.py (shared_trans)
	* oddities_list for those with forecast/original transform difference

## New Metric Checklist:
	* Create function in metrics.py
	* Add to mode base .evaluate()  (benchmark to make sure it is still fast)
	* Add to concat in TemplateWizard (if per_series metrics will be used)
	* Add to concat in TemplateEvalObject (if per_series metrics will be used)
	* Add to generate_score
	* Add to generate_score_per_series (if per_series metrics will be used)
	* Add to validation_aggregation
	* Update test_metrics results
